@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -54,10 +54,14 @@ namespace KeePass.App.Configuration
 	public enum AceUIFlags : ulong
 	{
 		None = 0,
+
 		DisableOptions = 0x1,
 		DisablePlugins = 0x2,
 		DisableTriggers = 0x4,
-		DisableKeyChangeDays = 0x8
+		DisableKeyChangeDays = 0x8,
+
+		HideBuiltInPwGenPrfInEntryDlg = 0x10000,
+		ShowLastAccessTime = 0x20000
 	}
 
 	[Flags]
