@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -111,6 +111,7 @@ namespace KeePass.DataExchange
 			m_vFormats.Add(new AmpXml250());
 			m_vFormats.Add(new AnyPwCsv144());
 			m_vFormats.Add(new CodeWalletTxt605());
+			m_vFormats.Add(new DashlaneCsv2());
 			m_vFormats.Add(new DataVaultCsv47());
 			m_vFormats.Add(new DesktopKnox32());
 			m_vFormats.Add(new FlexWalletXml17());
@@ -120,6 +121,7 @@ namespace KeePass.DataExchange
 			m_vFormats.Add(new KeePassXXml041());
 			m_vFormats.Add(new LastPassCsv2());
 			m_vFormats.Add(new NetworkPwMgrCsv4());
+			m_vFormats.Add(new NortonIdSafeCsv2013());
 			m_vFormats.Add(new PassKeeper12());
 			m_vFormats.Add(new PpKeeperHtml270());
 			m_vFormats.Add(new PwAgentXml234());
