@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@ using System;
 using System.Collections.Generic;
 using System.Text;
 using System.Runtime.InteropServices;
+using System.Globalization;
 using System.Diagnostics;
 
 using KeePass.Resources;
@@ -560,7 +561,8 @@ namespace KeePass.DataExchange
 				bool bProcessed = false;
 				for(int iIdx = 0; iIdx < 32; ++iIdx)
 				{
-					string s = ((iIdx == 0) ? string.Empty : "-" + iIdx.ToString());
+					string s = ((iIdx == 0) ? string.Empty : ("-" +
+						iIdx.ToString(NumberFormatInfo.InvariantInfo)));
 					string strWndPrefix = (AutoTypeWindowPrefix + s + ":");
 					string strSeqPrefix = (AutoTypePrefix + s + ":");
 
@@ -619,7 +621,7 @@ namespace KeePass.DataExchange
 				m_dSeq1xTo2x = new Dictionary<string, string>();
 				m_dSeq1xTo2xBiDir = new Dictionary<string, string>();
 
-				m_dSeq1xTo2x[@"{SPACE}"] = " ";
+				// m_dSeq1xTo2x[@"{SPACE}"] = " ";
 				// m_dSeq1xTo2x[@"{CLEARFIELD}"] = @"{HOME}+({END}){DEL}";
 
 				m_dSeq1xTo2xBiDir[@"{AT}"] = @"@";
@@ -727,7 +729,8 @@ namespace KeePass.DataExchange
 					bSeparator = true;
 				}
 
-				string strSuffix = ((uIndex > 0) ? ("-" + uIndex.ToString()) : string.Empty);
+				string strSuffix = ((uIndex > 0) ? ("-" + uIndex.ToString(
+					NumberFormatInfo.InvariantInfo)) : string.Empty);
 
 				sbAppend.Append(AutoTypePrefix + strSuffix);
 				sbAppend.Append(@": ");
