@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -385,7 +385,7 @@ namespace KeePass.Ecas
 
 		private static void CloseDatabaseFile(EcasAction a, EcasContext ctx)
 		{
-			Program.MainForm.CloseDocument(null, false, false);
+			Program.MainForm.CloseDocument(null, false, false, true);
 		}
 
 		private static void ActivateDatabaseTab(EcasAction a, EcasContext ctx)
