@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -186,7 +186,7 @@ namespace KeePass.Ecas
 			if(e == null) throw new ArgumentNullException("e");
 			if(ctx == null) throw new ArgumentNullException("ctx");
 
-			if(e.Type.EqualsValue(ctx.Event.Type) == false) return false;
+			if(e.Type.Equals(ctx.Event.Type) == false) return false;
 
 			foreach(EcasEventProvider p in m_vEventProviders)
 			{
