@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -60,9 +60,10 @@ namespace KeePass.Forms
 			Notes,
 			CustomString,
 			CreationTime,
-			LastAccessTime,
+			// LastAccessTime,
 			LastModTime,
 			ExpiryTime,
+			Tags,
 
 			Count, // Last enum item + 1
 			First = 0
@@ -177,6 +178,8 @@ namespace KeePass.Forms
 		{
 			if(m_bInitializing) return;
 
+			List<CsvFieldInfo> lFields = GetCsvFieldInfos();
+
 			bool bSelField = (m_lvFields.SelectedIndices.Count >= 1);
 			bool bSel1Field = (m_lvFields.SelectedIndices.Count == 1);
 			m_btnFieldDel.Enabled = bSelField;
@@ -237,6 +240,14 @@ namespace KeePass.Forms
 				else m_lblFieldFormat.Text = KPRes.Format + ":";
 			}
 			m_tLastCsvType = t;
+
+			bool bHasGroup = false;
+			foreach(CsvFieldInfo cfi in lFields)
+			{
+				if(cfi.Type == CsvFieldType.Group) { bHasGroup = true; break; }
+			}
+			if(!bHasGroup) m_cbMergeGroups.Checked = false;
+			m_cbMergeGroups.Enabled = bHasGroup;
 		}
 
 		private string GetDecodedText()
@@ -295,12 +306,14 @@ namespace KeePass.Forms
 				strText = KPRes.String;
 			else if(t == CsvFieldType.CreationTime)
 				strText = KPRes.CreationTime;
-			else if(t == CsvFieldType.LastAccessTime)
-				strText = KPRes.LastAccessTime;
+			// else if(t == CsvFieldType.LastAccessTime)
+			//	strText = KPRes.LastAccessTime;
 			else if(t == CsvFieldType.LastModTime)
 				strText = KPRes.LastModificationTime;
 			else if(t == CsvFieldType.ExpiryTime)
 				strText = KPRes.ExpiryTime;
+			else if(t == CsvFieldType.Tags)
+				strText = KPRes.Tags;
 			else { Debug.Assert(false); strText = KPRes.Unknown; }
 
 			return strText;
@@ -483,9 +496,10 @@ namespace KeePass.Forms
 			return opt;
 		}
 
-		private void PerformImport(PwGroup pgStorage, bool bCreatePreview)
+		private List<CsvFieldInfo> GetCsvFieldInfos()
 		{
 			List<CsvFieldInfo> lFields = new List<CsvFieldInfo>();
+
 			for(int i = 0; i < m_lvFields.Items.Count; ++i)
 			{
 				CsvFieldInfo cfi = (m_lvFields.Items[i].Tag as CsvFieldInfo);
@@ -493,6 +507,13 @@ namespace KeePass.Forms
 				lFields.Add(cfi);
 			}
 
+			return lFields;
+		}
+
+		private void PerformImport(PwGroup pgStorage, bool bCreatePreview)
+		{
+			List<CsvFieldInfo> lFields = GetCsvFieldInfos();
+
 			if(bCreatePreview)
 			{
 				int dx = m_lvImportPreview.ClientRectangle.Width; // Before clearing
@@ -524,6 +545,7 @@ namespace KeePass.Forms
 			DateTime dtNoExpire = KdbTime.NeverExpireTime.ToDateTime();
 			bool bIgnoreFirstRow = m_cbIgnoreFirst.Checked;
 			bool bIsFirstRow = true;
+			bool bMergeGroups = m_cbMergeGroups.Checked;
 
 			while(true)
 			{
@@ -551,7 +573,7 @@ namespace KeePass.Forms
 					if(cfi.Type == CsvFieldType.Ignore) { }
 					else if(cfi.Type == CsvFieldType.Group)
 						pg = FindCreateGroup(strField, pgStorage, dGroups,
-							cfi.Format, opt);
+							cfi.Format, opt, bMergeGroups);
 					else if(cfi.Type == CsvFieldType.Title)
 						ImportUtil.AppendToField(pe, PwDefs.TitleField,
 							strField, m_pwDatabase);
@@ -572,8 +594,8 @@ namespace KeePass.Forms
 							PwDefs.NotesField : cfi.Name), strField, m_pwDatabase);
 					else if(cfi.Type == CsvFieldType.CreationTime)
 						pe.CreationTime = ParseDateTime(ref strField, cfi, dtNow);
-					else if(cfi.Type == CsvFieldType.LastAccessTime)
-						pe.LastAccessTime = ParseDateTime(ref strField, cfi, dtNow);
+					// else if(cfi.Type == CsvFieldType.LastAccessTime)
+					//	pe.LastAccessTime = ParseDateTime(ref strField, cfi, dtNow);
 					else if(cfi.Type == CsvFieldType.LastModTime)
 						pe.LastModificationTime = ParseDateTime(ref strField, cfi, dtNow);
 					else if(cfi.Type == CsvFieldType.ExpiryTime)
@@ -583,6 +605,12 @@ namespace KeePass.Forms
 							out bParseSuccess);
 						pe.Expires = (bParseSuccess && (pe.ExpiryTime != dtNoExpire));
 					}
+					else if(cfi.Type == CsvFieldType.Tags)
+					{
+						List<string> lTags = StrUtil.StringToTags(strField);
+						foreach(string strTag in lTags)
+							pe.AddTag(strTag);
+					}
 					else { Debug.Assert(false); }
 
 					if(bCreatePreview)
@@ -614,14 +642,14 @@ namespace KeePass.Forms
 			}
 		}
 
-		private DateTime ParseDateTime(ref string strData, CsvFieldInfo cfi,
+		private static DateTime ParseDateTime(ref string strData, CsvFieldInfo cfi,
 			DateTime dtDefault)
 		{
 			bool bDummy;
 			return ParseDateTime(ref strData, cfi, dtDefault, out bDummy);
 		}
 
-		private DateTime ParseDateTime(ref string strData, CsvFieldInfo cfi,
+		private static DateTime ParseDateTime(ref string strData, CsvFieldInfo cfi,
 			DateTime dtDefault, out bool bSuccess)
 		{
 			DateTime? odt = null;
@@ -660,10 +688,11 @@ namespace KeePass.Forms
 			return odt.Value;
 		}
 
-		private static PwGroup FindCreateGroup(string strSpec, PwGroup pgStorage,
-			Dictionary<string, PwGroup> dRootGroups, string strSep, CsvOptions opt)
+		private static List<string> SplitGroupPath(string strSpec, string strSep,
+			CsvOptions opt)
 		{
 			List<string> l = new List<string>();
+
 			if(string.IsNullOrEmpty(strSep)) l.Add(strSpec);
 			else
 			{
@@ -678,6 +707,37 @@ namespace KeePass.Forms
 				if(l.Count == 0) l.Add(strSpec);
 			}
 
+			return l;
+		}
+
+		private static string AssembleGroupPath(List<string> l, int iOffset,
+			char chSep)
+		{
+			StringBuilder sb = new StringBuilder();
+
+			for(int i = iOffset; i < l.Count; ++i)
+			{
+				if(i > iOffset) sb.Append(chSep);
+				sb.Append(l[i]);
+			}
+
+			return sb.ToString();
+		}
+
+		private static PwGroup FindCreateGroup(string strSpec, PwGroup pgStorage,
+			Dictionary<string, PwGroup> dRootGroups, string strSep, CsvOptions opt,
+			bool bMergeGroups)
+		{
+			List<string> l = SplitGroupPath(strSpec, strSep, opt);
+
+			if(bMergeGroups)
+			{
+				char chSep = StrUtil.GetUnusedChar(strSpec);
+				string strPath = AssembleGroupPath(l, 0, chSep);
+
+				return pgStorage.FindCreateSubTree(strPath, new char[1] { chSep });
+			}
+
 			string strRootSub = l[0];
 			if(!dRootGroups.ContainsKey(strRootSub))
 			{
@@ -691,14 +751,9 @@ namespace KeePass.Forms
 			if(l.Count > 1)
 			{
 				char chSep = StrUtil.GetUnusedChar(strSpec);
-				StringBuilder sb = new StringBuilder();
-				for(int i = 1; i < l.Count; ++i)
-				{
-					if(i > 1) sb.Append(chSep);
-					sb.Append(l[i]);
-				}
+				string strSubPath = AssembleGroupPath(l, 1, chSep);
 
-				pg = pg.FindCreateSubTree(sb.ToString(), new char[1]{ chSep });
+				pg = pg.FindCreateSubTree(strSubPath, new char[1] { chSep });
 			}
 
 			return pg;
@@ -802,7 +857,7 @@ namespace KeePass.Forms
 				return new CsvFieldInfo(CsvFieldType.Notes, null, null);
 
 			string[] vGroupNames = new string[] {
-				"Password Groups", "Group", "Groups", "Group Tree"
+				"Password Groups", "Group", "Groups", "Group Tree", KPRes.Group
 			};
 			foreach(string strGroupName in vGroupNames)
 			{
@@ -820,15 +875,15 @@ namespace KeePass.Forms
 					return new CsvFieldInfo(CsvFieldType.CreationTime, null, null);
 			}
 
-			string[] vLastAccess = new string[] {
-				"Last Access", "Last Access Time",
-				KPRes.LastAccessTime
-			};
-			foreach(string strLastAccess in vLastAccess)
-			{
-				if(strName.Equals(strLastAccess, StrUtil.CaseIgnoreCmp))
-					return new CsvFieldInfo(CsvFieldType.LastAccessTime, null, null);
-			}
+			// string[] vLastAccess = new string[] {
+			//	"Last Access", "Last Access Time",
+			//	KPRes.LastAccessTime
+			// };
+			// foreach(string strLastAccess in vLastAccess)
+			// {
+			//	if(strName.Equals(strLastAccess, StrUtil.CaseIgnoreCmp))
+			//		return new CsvFieldInfo(CsvFieldType.LastAccessTime, null, null);
+			// }
 
 			string[] vLastMod = new string[] {
 				"Last Modification", "Last Mod", "Last Modification Time",
@@ -851,12 +906,22 @@ namespace KeePass.Forms
 					return new CsvFieldInfo(CsvFieldType.ExpiryTime, null, null);
 			}
 
+			string[] vTags = new string[] {
+				"Tags", "Tag", KPRes.Tags, KPRes.Tag
+			};
+			foreach(string strTag in vTags)
+			{
+				if(strName.Equals(strTag, StrUtil.CaseIgnoreCmp))
+					return new CsvFieldInfo(CsvFieldType.Tags, null, null);
+			}
+
 			return null;
 		}
 
 		private static bool IsTimeField(CsvFieldType t)
 		{
-			return ((t == CsvFieldType.CreationTime) || (t == CsvFieldType.LastAccessTime) ||
+			return ((t == CsvFieldType.CreationTime) ||
+				// (t == CsvFieldType.LastAccessTime) ||
 				(t == CsvFieldType.LastModTime) || (t == CsvFieldType.ExpiryTime));
 		}
 
