@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@ using KeePass.Resources;
 using KeePass.UI;
 using KeePass.Util;
 
+using KeePassLib;
 using KeePassLib.Utility;
 
 namespace KeePass.Forms
@@ -64,6 +65,12 @@ namespace KeePass.Forms
 		public event EventHandler<DvfContextEventArgs> DvfUpdating;
 		public event EventHandler<DvfContextEventArgs> DvfRelease;
 
+		public static bool SupportsDataType(BinaryDataClass bdc)
+		{
+			return ((bdc == BinaryDataClass.Text) || (bdc == BinaryDataClass.RichText) ||
+				(bdc == BinaryDataClass.Image) || (bdc == BinaryDataClass.WebDocument));
+		}
+
 		public void InitEx(string strDataDesc, byte[] pbData)
 		{
 			if(strDataDesc != null) m_strDataDesc = strDataDesc;
@@ -86,8 +93,10 @@ namespace KeePass.Forms
 
 			this.Icon = Properties.Resources.KeePass;
 
+			string strTitle = PwDefs.ShortProductName + " " + KPRes.DataViewer;
 			if(m_strDataDesc.Length > 0)
-				this.Text = m_strDataDesc + " - " + this.Text;
+				strTitle = m_strDataDesc + " - " + strTitle;
+			this.Text = strTitle;
 
 			this.DoubleBuffered = true;
 
