@@ -98,7 +98,7 @@
 			// m_lblKeySeqInsertInfo
 			// 
 			this.m_lblKeySeqInsertInfo.AutoSize = true;
-			this.m_lblKeySeqInsertInfo.Location = new System.Drawing.Point(119, 213);
+			this.m_lblKeySeqInsertInfo.Location = new System.Drawing.Point(29, 213);
 			this.m_lblKeySeqInsertInfo.Name = "m_lblKeySeqInsertInfo";
 			this.m_lblKeySeqInsertInfo.Size = new System.Drawing.Size(94, 13);
 			this.m_lblKeySeqInsertInfo.TabIndex = 6;
@@ -117,10 +117,10 @@
 			this.m_rbKeySeq.DetectUrls = false;
 			this.m_rbKeySeq.Font = new System.Drawing.Font("Courier New", 8.25F);
 			this.m_rbKeySeq.HideSelection = false;
-			this.m_rbKeySeq.Location = new System.Drawing.Point(122, 187);
+			this.m_rbKeySeq.Location = new System.Drawing.Point(32, 187);
 			this.m_rbKeySeq.Multiline = false;
 			this.m_rbKeySeq.Name = "m_rbKeySeq";
-			this.m_rbKeySeq.Size = new System.Drawing.Size(377, 20);
+			this.m_rbKeySeq.Size = new System.Drawing.Size(467, 20);
 			this.m_rbKeySeq.TabIndex = 5;
 			this.m_rbKeySeq.Text = "";
 			this.m_rbKeySeq.TextChanged += new System.EventHandler(this.OnTextChangedKeySeq);
@@ -128,21 +128,26 @@
 			// m_rtbPlaceholders
 			// 
 			this.m_rtbPlaceholders.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
-			this.m_rtbPlaceholders.Location = new System.Drawing.Point(122, 229);
+			this.m_rtbPlaceholders.Location = new System.Drawing.Point(32, 229);
 			this.m_rtbPlaceholders.Name = "m_rtbPlaceholders";
 			this.m_rtbPlaceholders.ReadOnly = true;
 			this.m_rtbPlaceholders.ScrollBars = System.Windows.Forms.RichTextBoxScrollBars.ForcedVertical;
-			this.m_rtbPlaceholders.Size = new System.Drawing.Size(377, 136);
+			this.m_rtbPlaceholders.Size = new System.Drawing.Size(467, 136);
 			this.m_rtbPlaceholders.TabIndex = 7;
 			this.m_rtbPlaceholders.Text = "";
 			this.m_rtbPlaceholders.LinkClicked += new System.Windows.Forms.LinkClickedEventHandler(this.OnPlaceholdersLinkClicked);
 			// 
 			// m_cmbWindow
 			// 
+			this.m_cmbWindow.DrawMode = System.Windows.Forms.DrawMode.OwnerDrawVariable;
+			this.m_cmbWindow.DropDownHeight = 218;
 			this.m_cmbWindow.FormattingEnabled = true;
-			this.m_cmbWindow.Location = new System.Drawing.Point(123, 72);
+			this.m_cmbWindow.IntegralHeight = false;
+			this.m_cmbWindow.Location = new System.Drawing.Point(95, 72);
+			this.m_cmbWindow.MaxDropDownItems = 12;
 			this.m_cmbWindow.Name = "m_cmbWindow";
-			this.m_cmbWindow.Size = new System.Drawing.Size(376, 21);
+			this.m_cmbWindow.OrderedImageList = null;
+			this.m_cmbWindow.Size = new System.Drawing.Size(404, 21);
 			this.m_cmbWindow.TabIndex = 0;
 			this.m_cmbWindow.SelectedIndexChanged += new System.EventHandler(this.OnWindowSelectedIndexChanged);
 			this.m_cmbWindow.TextUpdate += new System.EventHandler(this.OnWindowTextUpdate);
@@ -150,7 +155,7 @@
 			// m_lblOpenHint
 			// 
 			this.m_lblOpenHint.AutoSize = true;
-			this.m_lblOpenHint.Location = new System.Drawing.Point(120, 99);
+			this.m_lblOpenHint.Location = new System.Drawing.Point(92, 99);
 			this.m_lblOpenHint.Name = "m_lblOpenHint";
 			this.m_lblOpenHint.Size = new System.Drawing.Size(351, 13);
 			this.m_lblOpenHint.TabIndex = 1;
@@ -159,7 +164,7 @@
 			// m_lnkWildcardRegexHint
 			// 
 			this.m_lnkWildcardRegexHint.AutoSize = true;
-			this.m_lnkWildcardRegexHint.Location = new System.Drawing.Point(120, 116);
+			this.m_lnkWildcardRegexHint.Location = new System.Drawing.Point(92, 116);
 			this.m_lnkWildcardRegexHint.Name = "m_lnkWildcardRegexHint";
 			this.m_lnkWildcardRegexHint.Size = new System.Drawing.Size(270, 13);
 			this.m_lnkWildcardRegexHint.TabIndex = 2;
