@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -140,8 +140,13 @@ namespace KeePass.Forms
 			m_cmbKeyFile.Items.Add(KPRes.NoKeyFileSpecifiedMeta);
 			m_cmbKeyFile.SelectedIndex = 0;
 
-			if((Program.CommandLineArgs.FileName != null) &&
-				(m_ioInfo.Path == Program.CommandLineArgs.FileName))
+			// Do not directly compare with Program.CommandLineArgs.FileName,
+			// because this may be a relative path instead of an absolute one
+			string strCmdLineFile = Program.CommandLineArgs.FileName;
+			if((strCmdLineFile != null) && (Program.MainForm != null))
+				strCmdLineFile = Program.MainForm.IocFromCommandLine().Path;
+			if((strCmdLineFile != null) && strCmdLineFile.Equals(m_ioInfo.Path,
+				StrUtil.CaseIgnoreCmp))
 			{
 				string str;
 
