@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -168,7 +168,7 @@ namespace KeePass.Forms
 			m_dynCustomStrings.MenuClick += this.OnCopyCustomString;
 
 			m_dynCustomBinaries = new DynamicMenu(m_ctxEntryAttachments.DropDownItems);
-			m_dynCustomBinaries.MenuClick += this.OnEntryBinaryView;
+			m_dynCustomBinaries.MenuClick += this.OnEntryBinaryOpen;
 
 			m_dynShowEntriesByTagsEditMenu = new DynamicMenu(m_menuEditShowByTag.DropDownItems);
 			m_dynShowEntriesByTagsEditMenu.MenuClick += this.OnShowEntriesByTag;
@@ -592,7 +592,7 @@ namespace KeePass.Forms
 
 		private void OnFileClose(object sender, EventArgs e)
 		{
-			CloseDocument(null, false, false);
+			CloseDocument(null, false, false, true);
 		}
 
 		private void SaveDatabase(PwDatabase pdToSave, object sender)
@@ -917,11 +917,13 @@ namespace KeePass.Forms
 			}
 
 			AddEntriesToList(vNewEntries);
-			SelectEntries(vNewEntries, true, false);
+			SelectEntries(vNewEntries, true, true);
 
-			if(!m_lvEntries.ShowGroups && (m_lvEntries.Items.Count >= 1))
-				m_lvEntries.EnsureVisible(m_lvEntries.Items.Count - 1);
-			else EnsureVisibleSelected(true);
+			// if(!m_lvEntries.ShowGroups && (m_lvEntries.Items.Count >= 1))
+			//	m_lvEntries.EnsureVisible(m_lvEntries.Items.Count - 1);
+			// else EnsureVisibleSelected(true);
+			EnsureVisibleSelected(true); // Show all copies if possible
+			EnsureVisibleSelected(false); // Ensure showing the first
 
 			UpdateUIState(true, m_lvEntries);
 		}
@@ -969,6 +971,7 @@ namespace KeePass.Forms
 			if(!CloseAllDocuments(true))
 			{
 				e.Cancel = true;
+				UpdateUI(true, null, true, null, true, null, false);
 				return;
 			}
 
@@ -1179,7 +1182,7 @@ namespace KeePass.Forms
 			//	bHandled = true;
 			// }
 
-			if(bHandled) { e.Handled = true; e.SuppressKeyPress = true; }
+			if(bHandled) UIUtil.SetHandled(e, true);
 		}
 
 		private void OnQuickFindKeyUp(object sender, KeyEventArgs e)
@@ -1191,7 +1194,7 @@ namespace KeePass.Forms
 			// else if(e.KeyCode == Keys.Tab)
 			//	bHandled = true;
 
-			if(bHandled) { e.Handled = true; e.SuppressKeyPress = true; }
+			if(bHandled) UIUtil.SetHandled(e, true);
 		}
 
 		private void OnToolsOptions(object sender, EventArgs e)
@@ -1638,7 +1641,7 @@ namespace KeePass.Forms
 			{
 				foreach(PwEntry pe in vEntries)
 				{
-					if(ipf.ChosenCustomIconUuid != PwUuid.Zero)
+					if(!ipf.ChosenCustomIconUuid.Equals(PwUuid.Zero))
 						pe.CustomIconUuid = ipf.ChosenCustomIconUuid;
 					else
 					{
@@ -1726,7 +1729,7 @@ namespace KeePass.Forms
 				OnEntryEdit(sender, e);
 			else bUnhandled = true;
 
-			if(!bUnhandled) { e.Handled = true; e.SuppressKeyPress = true; }
+			if(!bUnhandled) UIUtil.SetHandled(e, true);
 		}
 
 		private void OnPwListKeyUp(object sender, KeyEventArgs e)
@@ -1765,7 +1768,7 @@ namespace KeePass.Forms
 			else if(e.KeyCode == Keys.F2) { }
 			else bUnhandled = true;
 
-			if(!bUnhandled) { e.Handled = true; e.SuppressKeyPress = true; }
+			if(!bUnhandled) UIUtil.SetHandled(e, true);
 		}
 
 		private void OnGroupsFind(object sender, EventArgs e)
@@ -1898,7 +1901,7 @@ namespace KeePass.Forms
 			else if(strEntryUrl == strLink)
 				PerformDefaultUrlAction(null, false);
 			else if(pb != null)
-				ExecuteBinaryEditView(strLink, pb);
+				ExecuteBinaryOpen(pe, strLink);
 			else if(strLink.StartsWith(SprEngine.StrRefStart, StrUtil.CaseIgnoreCmp) &&
 				strLink.EndsWith(SprEngine.StrRefEnd, StrUtil.CaseIgnoreCmp))
 			{
@@ -2042,9 +2045,6 @@ namespace KeePass.Forms
 			}
 			m_ctxEntryCopyCustomString.Visible = (uStrItems > 0);
 
-			LinkedList<KeyValuePair<string, Image>> lEditableBinaries =
-				new LinkedList<KeyValuePair<string, Image>>();
-
 			uint uBinItems = 0;
 			foreach(KeyValuePair<string, ProtectedBinary> kvp in pe.Binaries)
 			{
@@ -2060,24 +2060,13 @@ namespace KeePass.Forms
 					imgIcon = Properties.Resources.B16x16_HTML;
 				else imgIcon = Properties.Resources.B16x16_Binary;
 
-				m_dynCustomBinaries.AddItem(kvp.Key, imgIcon);
+				EntryBinaryDataContext ctxBin = new EntryBinaryDataContext();
+				ctxBin.Entry = pe;
+				ctxBin.Name = kvp.Key;
+
+				m_dynCustomBinaries.AddItem(kvp.Key, imgIcon, ctxBin);
 				++uBinItems;
-
-				if(DataEditorForm.SupportsDataType(bdc))
-					lEditableBinaries.AddLast(new KeyValuePair<string, Image>(
-						kvp.Key, imgIcon));
 			}
-
-			if(lEditableBinaries.Count > 0)
-			{
-				m_dynCustomBinaries.AddSeparator();
-
-				foreach(KeyValuePair<string, Image> kvpEdit in lEditableBinaries)
-					m_dynCustomBinaries.AddItem(string.Format(KPRes.EditObject + "...",
-						kvpEdit.Key), kvpEdit.Value, new EditableBinaryAttachment(
-						kvpEdit.Key));
-			}
-
 			m_ctxEntryAttachments.Visible = (uBinItems > 0);
 		}
 
@@ -2217,7 +2206,7 @@ namespace KeePass.Forms
 			}
 			else bUnhandled = true;
 
-			if(!bUnhandled) { e.Handled = true; e.SuppressKeyPress = true; }
+			if(!bUnhandled) UIUtil.SetHandled(e, true);
 		}
 
 		private void OnGroupsKeyUp(object sender, KeyEventArgs e)
@@ -2250,7 +2239,7 @@ namespace KeePass.Forms
 			}
 			else bUnhandled = true;
 
-			if(!bUnhandled) { e.Handled = true; e.SuppressKeyPress = true; }
+			if(!bUnhandled) UIUtil.SetHandled(e, true);
 		}
 
 		private void OnEntryUrlOpenInInternal(object sender, EventArgs e)
@@ -2394,7 +2383,7 @@ namespace KeePass.Forms
 						PwDocument pd = (m_tabMain.TabPages[i].Tag as PwDocument);
 						if(pd == null) { Debug.Assert(false); break; }
 
-						CloseDocument(pd, false, false);
+						CloseDocument(pd, false, false, true);
 						break;
 					}
 				}
@@ -2403,6 +2392,8 @@ namespace KeePass.Forms
 
 		private void OnViewConfigColumns(object sender, EventArgs e)
 		{
+			UpdateColumnsEx(true); // Save display indices
+
 			ColumnsForm dlg = new ColumnsForm();
 			if(UIUtil.ShowDialogAndDestroy(dlg) == DialogResult.OK)
 			{
@@ -2576,5 +2567,17 @@ namespace KeePass.Forms
 
 			UpdateUI(false, null, true, pg, true, null, true);
 		}
+
+		private void OnToolsXmlRep(object sender, EventArgs e)
+		{
+			PwDatabase pd = m_docMgr.ActiveDatabase;
+			if((pd == null) || !pd.IsOpen) { Debug.Assert(false); return; }
+
+			XmlReplaceForm dlg = new XmlReplaceForm();
+			dlg.InitEx(pd);
+
+			if(UIUtil.ShowDialogAndDestroy(dlg) == DialogResult.OK)
+				UpdateUI(false, null, true, null, true, null, false);
+		}
 	}
 }
