@@ -67,27 +67,31 @@
 			this.m_ttBalloon = new System.Windows.Forms.ToolTip(this.components);
 			this.m_tabMain = new System.Windows.Forms.TabControl();
 			this.m_tabEntry = new System.Windows.Forms.TabPage();
+			this.m_rtNotes = new KeePass.UI.CustomRichTextBoxEx();
+			this.m_pbQuality = new KeePass.UI.QualityProgressBar();
 			this.m_tabAdvanced = new System.Windows.Forms.TabPage();
 			this.m_grpAttachments = new System.Windows.Forms.GroupBox();
-			this.m_btnBinView = new System.Windows.Forms.Button();
+			this.m_btnBinOpen = new KeePass.UI.SplitButtonEx();
 			this.m_btnBinSave = new System.Windows.Forms.Button();
 			this.m_btnBinDelete = new System.Windows.Forms.Button();
 			this.m_btnBinAdd = new System.Windows.Forms.Button();
+			this.m_lvBinaries = new KeePass.UI.CustomListViewEx();
 			this.m_grpStringFields = new System.Windows.Forms.GroupBox();
 			this.m_btnStrMove = new System.Windows.Forms.Button();
 			this.m_btnStrAdd = new System.Windows.Forms.Button();
 			this.m_btnStrEdit = new System.Windows.Forms.Button();
 			this.m_btnStrDelete = new System.Windows.Forms.Button();
+			this.m_lvStrings = new KeePass.UI.CustomListViewEx();
 			this.m_ctxListOperations = new System.Windows.Forms.ContextMenuStrip(this.components);
 			this.m_menuListCtxCopyFieldValue = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_tabProperties = new System.Windows.Forms.TabPage();
+			this.m_cmbOverrideUrl = new KeePass.UI.ImageComboBoxEx();
 			this.m_tbTags = new System.Windows.Forms.TextBox();
 			this.m_lblTags = new System.Windows.Forms.Label();
 			this.m_btnPickFgColor = new System.Windows.Forms.Button();
 			this.m_cbCustomForegroundColor = new System.Windows.Forms.CheckBox();
 			this.m_tbUuid = new System.Windows.Forms.TextBox();
 			this.m_lblUuid = new System.Windows.Forms.Label();
-			this.m_tbOverrideUrl = new System.Windows.Forms.TextBox();
 			this.m_lblOverrideUrl = new System.Windows.Forms.Label();
 			this.m_cbCustomBackgroundColor = new System.Windows.Forms.CheckBox();
 			this.m_btnPickBgColor = new System.Windows.Forms.Button();
@@ -103,10 +107,12 @@
 			this.m_btnAutoTypeEdit = new System.Windows.Forms.Button();
 			this.m_btnAutoTypeAdd = new System.Windows.Forms.Button();
 			this.m_btnAutoTypeDelete = new System.Windows.Forms.Button();
+			this.m_lvAutoType = new KeePass.UI.CustomListViewEx();
 			this.m_tabHistory = new System.Windows.Forms.TabPage();
 			this.m_btnHistoryDelete = new System.Windows.Forms.Button();
 			this.m_btnHistoryView = new System.Windows.Forms.Button();
 			this.m_btnHistoryRestore = new System.Windows.Forms.Button();
+			this.m_lvHistory = new KeePass.UI.CustomListViewEx();
 			this.m_btnTools = new System.Windows.Forms.Button();
 			this.m_bannerImage = new System.Windows.Forms.PictureBox();
 			this.m_ctxStrMoveToStandard = new System.Windows.Forms.ContextMenuStrip(this.components);
@@ -117,8 +123,6 @@
 			this.m_menuListCtxMoveStandardNotes = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_ctxPwGen = new System.Windows.Forms.ContextMenuStrip(this.components);
 			this.m_ctxPwGenOpen = new System.Windows.Forms.ToolStripMenuItem();
-			this.m_ctxPwGenSep0 = new System.Windows.Forms.ToolStripSeparator();
-			this.m_ctxPwGenProfiles = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_ctxTools = new System.Windows.Forms.ContextMenuStrip(this.components);
 			this.m_ctxToolsHelp = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_ctxToolsSep0 = new System.Windows.Forms.ToolStripSeparator();
@@ -136,12 +140,6 @@
 			this.m_ctxBinImportFile = new System.Windows.Forms.ToolStripMenuItem();
 			this.m_ctxBinSep0 = new System.Windows.Forms.ToolStripSeparator();
 			this.m_ctxBinNew = new System.Windows.Forms.ToolStripMenuItem();
-			this.m_rtNotes = new KeePass.UI.CustomRichTextBoxEx();
-			this.m_pbQuality = new KeePass.UI.QualityProgressBar();
-			this.m_lvBinaries = new KeePass.UI.CustomListViewEx();
-			this.m_lvStrings = new KeePass.UI.CustomListViewEx();
-			this.m_lvAutoType = new KeePass.UI.CustomListViewEx();
-			this.m_lvHistory = new KeePass.UI.CustomListViewEx();
 			this.m_ctxDefaultTimes.SuspendLayout();
 			this.m_tabMain.SuspendLayout();
 			this.m_tabEntry.SuspendLayout();
@@ -501,6 +499,28 @@
 			this.m_tabEntry.Text = "Entry";
 			this.m_tabEntry.UseVisualStyleBackColor = true;
 			// 
+			// m_rtNotes
+			// 
+			this.m_rtNotes.Location = new System.Drawing.Point(81, 167);
+			this.m_rtNotes.Name = "m_rtNotes";
+			this.m_rtNotes.ScrollBars = System.Windows.Forms.RichTextBoxScrollBars.Vertical;
+			this.m_rtNotes.Size = new System.Drawing.Size(374, 140);
+			this.m_rtNotes.TabIndex = 18;
+			this.m_rtNotes.Text = "";
+			this.m_rtNotes.LinkClicked += new System.Windows.Forms.LinkClickedEventHandler(this.OnNotesLinkClicked);
+			// 
+			// m_pbQuality
+			// 
+			this.m_pbQuality.Location = new System.Drawing.Point(81, 118);
+			this.m_pbQuality.Maximum = 100;
+			this.m_pbQuality.Minimum = 0;
+			this.m_pbQuality.Name = "m_pbQuality";
+			this.m_pbQuality.Size = new System.Drawing.Size(283, 16);
+			this.m_pbQuality.Style = System.Windows.Forms.ProgressBarStyle.Continuous;
+			this.m_pbQuality.TabIndex = 13;
+			this.m_pbQuality.TabStop = false;
+			this.m_pbQuality.Value = 50;
+			// 
 			// m_tabAdvanced
 			// 
 			this.m_tabAdvanced.Controls.Add(this.m_grpAttachments);
@@ -515,7 +535,7 @@
 			// 
 			// m_grpAttachments
 			// 
-			this.m_grpAttachments.Controls.Add(this.m_btnBinView);
+			this.m_grpAttachments.Controls.Add(this.m_btnBinOpen);
 			this.m_grpAttachments.Controls.Add(this.m_btnBinSave);
 			this.m_grpAttachments.Controls.Add(this.m_btnBinDelete);
 			this.m_grpAttachments.Controls.Add(this.m_btnBinAdd);
@@ -527,15 +547,15 @@
 			this.m_grpAttachments.TabStop = false;
 			this.m_grpAttachments.Text = "File attachments";
 			// 
-			// m_btnBinView
+			// m_btnBinOpen
 			// 
-			this.m_btnBinView.Location = new System.Drawing.Point(374, 104);
-			this.m_btnBinView.Name = "m_btnBinView";
-			this.m_btnBinView.Size = new System.Drawing.Size(75, 23);
-			this.m_btnBinView.TabIndex = 3;
-			this.m_btnBinView.Text = "<>";
-			this.m_btnBinView.UseVisualStyleBackColor = true;
-			this.m_btnBinView.Click += new System.EventHandler(this.OnBtnBinView);
+			this.m_btnBinOpen.Location = new System.Drawing.Point(374, 104);
+			this.m_btnBinOpen.Name = "m_btnBinOpen";
+			this.m_btnBinOpen.Size = new System.Drawing.Size(75, 23);
+			this.m_btnBinOpen.TabIndex = 3;
+			this.m_btnBinOpen.Text = "O&pen";
+			this.m_btnBinOpen.UseVisualStyleBackColor = true;
+			this.m_btnBinOpen.Click += new System.EventHandler(this.OnBtnBinOpen);
 			// 
 			// m_btnBinSave
 			// 
@@ -567,6 +587,27 @@
 			this.m_btnBinAdd.UseVisualStyleBackColor = true;
 			this.m_btnBinAdd.Click += new System.EventHandler(this.OnBtnBinAdd);
 			// 
+			// m_lvBinaries
+			// 
+			this.m_lvBinaries.AllowDrop = true;
+			this.m_lvBinaries.FullRowSelect = true;
+			this.m_lvBinaries.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.Nonclickable;
+			this.m_lvBinaries.HideSelection = false;
+			this.m_lvBinaries.LabelEdit = true;
+			this.m_lvBinaries.Location = new System.Drawing.Point(6, 20);
+			this.m_lvBinaries.Name = "m_lvBinaries";
+			this.m_lvBinaries.ShowItemToolTips = true;
+			this.m_lvBinaries.Size = new System.Drawing.Size(362, 135);
+			this.m_lvBinaries.TabIndex = 0;
+			this.m_lvBinaries.UseCompatibleStateImageBehavior = false;
+			this.m_lvBinaries.View = System.Windows.Forms.View.Details;
+			this.m_lvBinaries.ItemActivate += new System.EventHandler(this.OnBinariesItemActivate);
+			this.m_lvBinaries.AfterLabelEdit += new System.Windows.Forms.LabelEditEventHandler(this.OnBinAfterLabelEdit);
+			this.m_lvBinaries.SelectedIndexChanged += new System.EventHandler(this.OnBinariesSelectedIndexChanged);
+			this.m_lvBinaries.DragDrop += new System.Windows.Forms.DragEventHandler(this.OnBinDragDrop);
+			this.m_lvBinaries.DragEnter += new System.Windows.Forms.DragEventHandler(this.OnBinDragEnter);
+			this.m_lvBinaries.DragOver += new System.Windows.Forms.DragEventHandler(this.OnBinDragOver);
+			// 
 			// m_grpStringFields
 			// 
 			this.m_grpStringFields.Controls.Add(this.m_btnStrMove);
@@ -621,6 +662,22 @@
 			this.m_btnStrDelete.UseVisualStyleBackColor = true;
 			this.m_btnStrDelete.Click += new System.EventHandler(this.OnBtnStrDelete);
 			// 
+			// m_lvStrings
+			// 
+			this.m_lvStrings.ContextMenuStrip = this.m_ctxListOperations;
+			this.m_lvStrings.FullRowSelect = true;
+			this.m_lvStrings.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.Nonclickable;
+			this.m_lvStrings.HideSelection = false;
+			this.m_lvStrings.Location = new System.Drawing.Point(6, 20);
+			this.m_lvStrings.Name = "m_lvStrings";
+			this.m_lvStrings.ShowItemToolTips = true;
+			this.m_lvStrings.Size = new System.Drawing.Size(362, 135);
+			this.m_lvStrings.TabIndex = 0;
+			this.m_lvStrings.UseCompatibleStateImageBehavior = false;
+			this.m_lvStrings.View = System.Windows.Forms.View.Details;
+			this.m_lvStrings.ItemActivate += new System.EventHandler(this.OnStringsItemActivate);
+			this.m_lvStrings.SelectedIndexChanged += new System.EventHandler(this.OnStringsSelectedIndexChanged);
+			// 
 			// m_ctxListOperations
 			// 
 			this.m_ctxListOperations.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
@@ -638,13 +695,13 @@
 			// 
 			// m_tabProperties
 			// 
+			this.m_tabProperties.Controls.Add(this.m_cmbOverrideUrl);
 			this.m_tabProperties.Controls.Add(this.m_tbTags);
 			this.m_tabProperties.Controls.Add(this.m_lblTags);
 			this.m_tabProperties.Controls.Add(this.m_btnPickFgColor);
 			this.m_tabProperties.Controls.Add(this.m_cbCustomForegroundColor);
 			this.m_tabProperties.Controls.Add(this.m_tbUuid);
 			this.m_tabProperties.Controls.Add(this.m_lblUuid);
-			this.m_tabProperties.Controls.Add(this.m_tbOverrideUrl);
 			this.m_tabProperties.Controls.Add(this.m_lblOverrideUrl);
 			this.m_tabProperties.Controls.Add(this.m_cbCustomBackgroundColor);
 			this.m_tabProperties.Controls.Add(this.m_btnPickBgColor);
@@ -655,6 +712,19 @@
 			this.m_tabProperties.Text = "Properties";
 			this.m_tabProperties.UseVisualStyleBackColor = true;
 			// 
+			// m_cmbOverrideUrl
+			// 
+			this.m_cmbOverrideUrl.DrawMode = System.Windows.Forms.DrawMode.OwnerDrawVariable;
+			this.m_cmbOverrideUrl.DropDownHeight = 218;
+			this.m_cmbOverrideUrl.FormattingEnabled = true;
+			this.m_cmbOverrideUrl.IntegralHeight = false;
+			this.m_cmbOverrideUrl.Location = new System.Drawing.Point(9, 144);
+			this.m_cmbOverrideUrl.MaxDropDownItems = 16;
+			this.m_cmbOverrideUrl.Name = "m_cmbOverrideUrl";
+			this.m_cmbOverrideUrl.OrderedImageList = null;
+			this.m_cmbOverrideUrl.Size = new System.Drawing.Size(447, 21);
+			this.m_cmbOverrideUrl.TabIndex = 7;
+			// 
 			// m_tbTags
 			// 
 			this.m_tbTags.Location = new System.Drawing.Point(9, 94);
@@ -708,21 +778,14 @@
 			this.m_lblUuid.TabIndex = 8;
 			this.m_lblUuid.Text = "UUID:";
 			// 
-			// m_tbOverrideUrl
-			// 
-			this.m_tbOverrideUrl.Location = new System.Drawing.Point(9, 144);
-			this.m_tbOverrideUrl.Name = "m_tbOverrideUrl";
-			this.m_tbOverrideUrl.Size = new System.Drawing.Size(447, 20);
-			this.m_tbOverrideUrl.TabIndex = 7;
-			// 
 			// m_lblOverrideUrl
 			// 
 			this.m_lblOverrideUrl.AutoSize = true;
 			this.m_lblOverrideUrl.Location = new System.Drawing.Point(6, 126);
 			this.m_lblOverrideUrl.Name = "m_lblOverrideUrl";
-			this.m_lblOverrideUrl.Size = new System.Drawing.Size(75, 13);
+			this.m_lblOverrideUrl.Size = new System.Drawing.Size(222, 13);
 			this.m_lblOverrideUrl.TabIndex = 6;
-			this.m_lblOverrideUrl.Text = "Override URL:";
+			this.m_lblOverrideUrl.Text = "Override URL (e.g. to use a specific browser):";
 			// 
 			// m_cbCustomBackgroundColor
 			// 
@@ -877,6 +940,22 @@
 			this.m_btnAutoTypeDelete.UseVisualStyleBackColor = true;
 			this.m_btnAutoTypeDelete.Click += new System.EventHandler(this.OnBtnAutoTypeDelete);
 			// 
+			// m_lvAutoType
+			// 
+			this.m_lvAutoType.ContextMenuStrip = this.m_ctxListOperations;
+			this.m_lvAutoType.FullRowSelect = true;
+			this.m_lvAutoType.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.Nonclickable;
+			this.m_lvAutoType.HideSelection = false;
+			this.m_lvAutoType.Location = new System.Drawing.Point(9, 134);
+			this.m_lvAutoType.Name = "m_lvAutoType";
+			this.m_lvAutoType.ShowItemToolTips = true;
+			this.m_lvAutoType.Size = new System.Drawing.Size(367, 170);
+			this.m_lvAutoType.TabIndex = 6;
+			this.m_lvAutoType.UseCompatibleStateImageBehavior = false;
+			this.m_lvAutoType.View = System.Windows.Forms.View.Details;
+			this.m_lvAutoType.ItemActivate += new System.EventHandler(this.OnAutoTypeItemActivate);
+			this.m_lvAutoType.SelectedIndexChanged += new System.EventHandler(this.OnAutoTypeSelectedIndexChanged);
+			// 
 			// m_tabHistory
 			// 
 			this.m_tabHistory.Controls.Add(this.m_btnHistoryDelete);
@@ -921,6 +1000,21 @@
 			this.m_btnHistoryRestore.UseVisualStyleBackColor = true;
 			this.m_btnHistoryRestore.Click += new System.EventHandler(this.OnBtnHistoryRestore);
 			// 
+			// m_lvHistory
+			// 
+			this.m_lvHistory.FullRowSelect = true;
+			this.m_lvHistory.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.Nonclickable;
+			this.m_lvHistory.HideSelection = false;
+			this.m_lvHistory.Location = new System.Drawing.Point(9, 13);
+			this.m_lvHistory.Name = "m_lvHistory";
+			this.m_lvHistory.ShowItemToolTips = true;
+			this.m_lvHistory.Size = new System.Drawing.Size(447, 288);
+			this.m_lvHistory.TabIndex = 0;
+			this.m_lvHistory.UseCompatibleStateImageBehavior = false;
+			this.m_lvHistory.View = System.Windows.Forms.View.Details;
+			this.m_lvHistory.ItemActivate += new System.EventHandler(this.OnHistoryItemActivate);
+			this.m_lvHistory.SelectedIndexChanged += new System.EventHandler(this.OnHistorySelectedIndexChanged);
+			// 
 			// m_btnTools
 			// 
 			this.m_btnTools.Location = new System.Drawing.Point(6, 453);
@@ -990,11 +1084,9 @@
 			// m_ctxPwGen
 			// 
 			this.m_ctxPwGen.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
-            this.m_ctxPwGenOpen,
-            this.m_ctxPwGenSep0,
-            this.m_ctxPwGenProfiles});
+            this.m_ctxPwGenOpen});
 			this.m_ctxPwGen.Name = "m_ctxPwGen";
-			this.m_ctxPwGen.Size = new System.Drawing.Size(229, 54);
+			this.m_ctxPwGen.Size = new System.Drawing.Size(229, 26);
 			// 
 			// m_ctxPwGenOpen
 			// 
@@ -1004,17 +1096,6 @@
 			this.m_ctxPwGenOpen.Text = "&Open Password Generator...";
 			this.m_ctxPwGenOpen.Click += new System.EventHandler(this.OnPwGenOpen);
 			// 
-			// m_ctxPwGenSep0
-			// 
-			this.m_ctxPwGenSep0.Name = "m_ctxPwGenSep0";
-			this.m_ctxPwGenSep0.Size = new System.Drawing.Size(225, 6);
-			// 
-			// m_ctxPwGenProfiles
-			// 
-			this.m_ctxPwGenProfiles.Name = "m_ctxPwGenProfiles";
-			this.m_ctxPwGenProfiles.Size = new System.Drawing.Size(228, 22);
-			this.m_ctxPwGenProfiles.Text = "Generate Using Profile";
-			// 
 			// m_ctxTools
 			// 
 			this.m_ctxTools.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
@@ -1147,96 +1228,6 @@
 			this.m_ctxBinNew.Text = "&Create Empty Attachment";
 			this.m_ctxBinNew.Click += new System.EventHandler(this.OnCtxBinNew);
 			// 
-			// m_rtNotes
-			// 
-			this.m_rtNotes.Location = new System.Drawing.Point(81, 167);
-			this.m_rtNotes.Name = "m_rtNotes";
-			this.m_rtNotes.ScrollBars = System.Windows.Forms.RichTextBoxScrollBars.Vertical;
-			this.m_rtNotes.Size = new System.Drawing.Size(374, 140);
-			this.m_rtNotes.TabIndex = 18;
-			this.m_rtNotes.Text = "";
-			this.m_rtNotes.LinkClicked += new System.Windows.Forms.LinkClickedEventHandler(this.OnNotesLinkClicked);
-			// 
-			// m_pbQuality
-			// 
-			this.m_pbQuality.Location = new System.Drawing.Point(81, 118);
-			this.m_pbQuality.Maximum = 100;
-			this.m_pbQuality.Minimum = 0;
-			this.m_pbQuality.Name = "m_pbQuality";
-			this.m_pbQuality.Size = new System.Drawing.Size(283, 16);
-			this.m_pbQuality.Style = System.Windows.Forms.ProgressBarStyle.Continuous;
-			this.m_pbQuality.TabIndex = 13;
-			this.m_pbQuality.TabStop = false;
-			this.m_pbQuality.Value = 50;
-			// 
-			// m_lvBinaries
-			// 
-			this.m_lvBinaries.AllowDrop = true;
-			this.m_lvBinaries.FullRowSelect = true;
-			this.m_lvBinaries.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.Nonclickable;
-			this.m_lvBinaries.HideSelection = false;
-			this.m_lvBinaries.LabelEdit = true;
-			this.m_lvBinaries.Location = new System.Drawing.Point(6, 20);
-			this.m_lvBinaries.Name = "m_lvBinaries";
-			this.m_lvBinaries.ShowItemToolTips = true;
-			this.m_lvBinaries.Size = new System.Drawing.Size(362, 135);
-			this.m_lvBinaries.TabIndex = 0;
-			this.m_lvBinaries.UseCompatibleStateImageBehavior = false;
-			this.m_lvBinaries.View = System.Windows.Forms.View.Details;
-			this.m_lvBinaries.ItemActivate += new System.EventHandler(this.OnBinariesItemActivate);
-			this.m_lvBinaries.AfterLabelEdit += new System.Windows.Forms.LabelEditEventHandler(this.OnBinAfterLabelEdit);
-			this.m_lvBinaries.SelectedIndexChanged += new System.EventHandler(this.OnBinariesSelectedIndexChanged);
-			this.m_lvBinaries.DragDrop += new System.Windows.Forms.DragEventHandler(this.OnBinDragDrop);
-			this.m_lvBinaries.DragEnter += new System.Windows.Forms.DragEventHandler(this.OnBinDragEnter);
-			this.m_lvBinaries.DragOver += new System.Windows.Forms.DragEventHandler(this.OnBinDragOver);
-			// 
-			// m_lvStrings
-			// 
-			this.m_lvStrings.ContextMenuStrip = this.m_ctxListOperations;
-			this.m_lvStrings.FullRowSelect = true;
-			this.m_lvStrings.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.Nonclickable;
-			this.m_lvStrings.HideSelection = false;
-			this.m_lvStrings.Location = new System.Drawing.Point(6, 20);
-			this.m_lvStrings.Name = "m_lvStrings";
-			this.m_lvStrings.ShowItemToolTips = true;
-			this.m_lvStrings.Size = new System.Drawing.Size(362, 135);
-			this.m_lvStrings.TabIndex = 0;
-			this.m_lvStrings.UseCompatibleStateImageBehavior = false;
-			this.m_lvStrings.View = System.Windows.Forms.View.Details;
-			this.m_lvStrings.ItemActivate += new System.EventHandler(this.OnStringsItemActivate);
-			this.m_lvStrings.SelectedIndexChanged += new System.EventHandler(this.OnStringsSelectedIndexChanged);
-			// 
-			// m_lvAutoType
-			// 
-			this.m_lvAutoType.ContextMenuStrip = this.m_ctxListOperations;
-			this.m_lvAutoType.FullRowSelect = true;
-			this.m_lvAutoType.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.Nonclickable;
-			this.m_lvAutoType.HideSelection = false;
-			this.m_lvAutoType.Location = new System.Drawing.Point(9, 134);
-			this.m_lvAutoType.Name = "m_lvAutoType";
-			this.m_lvAutoType.ShowItemToolTips = true;
-			this.m_lvAutoType.Size = new System.Drawing.Size(367, 170);
-			this.m_lvAutoType.TabIndex = 6;
-			this.m_lvAutoType.UseCompatibleStateImageBehavior = false;
-			this.m_lvAutoType.View = System.Windows.Forms.View.Details;
-			this.m_lvAutoType.ItemActivate += new System.EventHandler(this.OnAutoTypeItemActivate);
-			this.m_lvAutoType.SelectedIndexChanged += new System.EventHandler(this.OnAutoTypeSelectedIndexChanged);
-			// 
-			// m_lvHistory
-			// 
-			this.m_lvHistory.FullRowSelect = true;
-			this.m_lvHistory.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.Nonclickable;
-			this.m_lvHistory.HideSelection = false;
-			this.m_lvHistory.Location = new System.Drawing.Point(9, 13);
-			this.m_lvHistory.Name = "m_lvHistory";
-			this.m_lvHistory.ShowItemToolTips = true;
-			this.m_lvHistory.Size = new System.Drawing.Size(447, 288);
-			this.m_lvHistory.TabIndex = 0;
-			this.m_lvHistory.UseCompatibleStateImageBehavior = false;
-			this.m_lvHistory.View = System.Windows.Forms.View.Details;
-			this.m_lvHistory.ItemActivate += new System.EventHandler(this.OnHistoryItemActivate);
-			this.m_lvHistory.SelectedIndexChanged += new System.EventHandler(this.OnHistorySelectedIndexChanged);
-			// 
 			// PwEntryForm
 			// 
 			this.AcceptButton = this.m_btnOK;
@@ -1364,16 +1355,13 @@
 		private System.Windows.Forms.ToolStripMenuItem m_menuListCtxMoveStandardNotes;
 		private System.Windows.Forms.ContextMenuStrip m_ctxPwGen;
 		private System.Windows.Forms.ToolStripMenuItem m_ctxPwGenOpen;
-		private System.Windows.Forms.ToolStripSeparator m_ctxPwGenSep0;
-		private System.Windows.Forms.ToolStripMenuItem m_ctxPwGenProfiles;
 		private System.Windows.Forms.TabPage m_tabProperties;
 		private System.Windows.Forms.Button m_btnPickBgColor;
 		private System.Windows.Forms.CheckBox m_cbCustomBackgroundColor;
-		private System.Windows.Forms.TextBox m_tbOverrideUrl;
 		private System.Windows.Forms.Label m_lblOverrideUrl;
 		private System.Windows.Forms.LinkLabel m_linkAutoTypeObfuscation;
 		private System.Windows.Forms.CheckBox m_cbAutoTypeObfuscation;
-		private System.Windows.Forms.Button m_btnBinView;
+		private KeePass.UI.SplitButtonEx m_btnBinOpen;
 		private System.Windows.Forms.TextBox m_tbUuid;
 		private System.Windows.Forms.Label m_lblUuid;
 		private System.Windows.Forms.ContextMenuStrip m_ctxTools;
@@ -1397,6 +1385,7 @@
 		private System.Windows.Forms.ToolStripMenuItem m_ctxBinImportFile;
 		private System.Windows.Forms.ToolStripSeparator m_ctxBinSep0;
 		private System.Windows.Forms.ToolStripMenuItem m_ctxBinNew;
+		private KeePass.UI.ImageComboBoxEx m_cmbOverrideUrl;
 
 	}
 }
\ No newline at end of file
