@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -23,9 +23,10 @@ using System.ComponentModel;
 using System.Drawing;
 using System.Text;
 using System.Windows.Forms;
-using System.Diagnostics;
 using System.Globalization;
 using System.IO;
+using System.Threading;
+using System.Diagnostics;
 
 using KeePass.App;
 using KeePass.App.Configuration;
@@ -38,6 +39,7 @@ using KeePassLib;
 using KeePassLib.Collections;
 using KeePassLib.Cryptography;
 using KeePassLib.Cryptography.PasswordGenerator;
+using KeePassLib.Delegates;
 using KeePassLib.Security;
 using KeePassLib.Utility;
 
@@ -82,8 +84,15 @@ namespace KeePass.Forms
 		private RichTextBoxContextMenu m_ctxNotes = new RichTextBoxContextMenu();
 		private Image m_imgPwGen = null;
 		private Image m_imgStdExpire = null;
+		private List<Image> m_lOverrideUrlIcons = new List<Image>();
 
-		private readonly string DeriveFromPrevious = "(" + KPRes.GenPwBasedOnPrevious + ")";
+		private ContextMenuStrip m_ctxBinOpen = null;
+		private DynamicMenu m_dynBinOpen = null;
+
+		private readonly string DeriveFromPrevious = "(" +
+			KPRes.GenPwBasedOnPrevious + ")";
+		private readonly string AutoGenProfile = "(" +
+			KPRes.AutoGeneratedPasswordSettings + ")";
 		private DynamicMenu m_dynGenProfiles;
 
 		private const PwIcon m_pwObjectProtected = PwIcon.PaperLocked;
@@ -189,7 +198,7 @@ namespace KeePass.Forms
 			m_pwEntryIcon = m_pwEntry.IconId;
 			m_pwCustomIconID = m_pwEntry.CustomIconUuid;
 
-			if(m_pwCustomIconID != PwUuid.Zero)
+			if(!m_pwCustomIconID.Equals(PwUuid.Zero))
 			{
 				// int nInx = (int)PwIcon.Count + m_pwDatabase.GetCustomIconIndex(m_pwCustomIconID);
 				// if((nInx > -1) && (nInx < m_ilIcons.Images.Count))
@@ -271,8 +280,10 @@ namespace KeePass.Forms
 			{
 				m_btnStrAdd.Enabled = m_btnStrEdit.Enabled =
 					m_btnStrDelete.Enabled = m_btnStrMove.Enabled =
-					m_btnBinAdd.Enabled = m_btnBinDelete.Enabled =
-					m_btnBinView.Enabled = m_btnBinSave.Enabled = false;
+					m_btnBinAdd.Enabled = m_btnBinDelete.Enabled = false;
+
+				// Always available:
+				// m_btnBinOpen.Enabled = m_btnBinSave.Enabled = false;
 
 				m_lvBinaries.LabelEdit = false;
 			}
@@ -400,7 +411,7 @@ namespace KeePass.Forms
 			m_cbCustomForegroundColor.Checked = (m_clrForeground != Color.Empty);
 			m_cbCustomBackgroundColor.Checked = (m_clrBackground != Color.Empty);
 
-			m_tbOverrideUrl.Text = m_pwEntry.OverrideUrl;
+			m_cmbOverrideUrl.Text = m_pwEntry.OverrideUrl;
 			m_tbTags.Text = StrUtil.TagsToString(m_pwEntry.Tags, true);
 
 			if(m_pwEditMode == PwEditMode.ViewReadOnlyEntry)
@@ -409,7 +420,7 @@ namespace KeePass.Forms
 				m_cbCustomBackgroundColor.Enabled = false;
 				m_btnPickFgColor.Enabled = false;
 				m_btnPickBgColor.Enabled = false;
-				m_tbOverrideUrl.ReadOnly = true;
+				m_cmbOverrideUrl.Enabled = false;
 				m_tbTags.ReadOnly = true;
 			}
 
@@ -556,10 +567,16 @@ namespace KeePass.Forms
 
 			m_ttBalloon.SetToolTip(m_tbRepeatPassword, KPRes.PasswordRepeatHint);
 
-			m_dynGenProfiles = new DynamicMenu(m_ctxPwGenProfiles.DropDownItems);
+			m_dynGenProfiles = new DynamicMenu(m_ctxPwGen.Items);
 			m_dynGenProfiles.MenuClick += this.OnProfilesDynamicMenuClick;
 			m_ctxNotes.Attach(m_rtNotes, this);
 
+			m_ctxBinOpen = new ContextMenuStrip();
+			m_ctxBinOpen.Opening += this.OnCtxBinOpenOpening;
+			m_dynBinOpen = new DynamicMenu(m_ctxBinOpen.Items);
+			m_dynBinOpen.MenuClick += this.OnDynBinOpen;
+			m_btnBinOpen.SplitDropDownMenu = m_ctxBinOpen;
+
 			string strTitle = string.Empty, strDesc = string.Empty;
 			if(m_pwEditMode == PwEditMode.AddNewEntry)
 			{
@@ -636,6 +653,12 @@ namespace KeePass.Forms
 			ResizeColumnHeaders();
 			EnableControlsEx();
 
+			ThreadPool.QueueUserWorkItem(delegate(object state)
+			{
+				try { InitOverridesBox(); }
+				catch(Exception) { Debug.Assert(false); }
+			});
+
 			if(m_pwEditMode == PwEditMode.ViewReadOnlyEntry)
 				m_btnCancel.Select();
 			else
@@ -667,34 +690,15 @@ namespace KeePass.Forms
 			int nStringsSel = m_lvStrings.SelectedItems.Count;
 			int nBinSel = m_lvBinaries.SelectedItems.Count;
 
-			bool bBinEdit = false;
-			if(nBinSel == 1)
-			{
-				string strBin = m_lvBinaries.SelectedItems[0].Text;
-				ProtectedBinary pbSel = m_vBinaries.Get(strBin);
-				if(pbSel != null)
-				{
-					byte[] pbBinData = pbSel.ReadData();
-					BinaryDataClass bdc = BinaryDataClassifier.Classify(
-						strBin, pbBinData);
-					MemUtil.ZeroByteArray(pbBinData);
-					if(DataEditorForm.SupportsDataType(bdc) && (m_pwEditMode !=
-						PwEditMode.ViewReadOnlyEntry))
-						bBinEdit = true;
-				}
-				else { Debug.Assert(false); }
-			}
-			m_btnBinView.Text = (bBinEdit ? StrUtil.RemoveAccelerator(
-				KPRes.EditCmd) : KPRes.ViewCmd);
-
-			m_btnBinView.Enabled = (nBinSel == 1);
+			m_btnBinOpen.Enabled = (nBinSel == 1);
+			m_btnBinSave.Enabled = (nBinSel >= 1);
 
 			if(m_bLockEnabledState) return;
 
 			m_btnStrEdit.Enabled = (nStringsSel == 1);
 			m_btnStrDelete.Enabled = (nStringsSel >= 1);
 
-			m_btnBinSave.Enabled = m_btnBinDelete.Enabled = (nBinSel >= 1);
+			m_btnBinDelete.Enabled = (nBinSel >= 1);
 
 			m_btnPickFgColor.Enabled = m_cbCustomForegroundColor.Checked;
 			m_btnPickBgColor.Enabled = m_cbCustomBackgroundColor.Checked;
@@ -758,7 +762,7 @@ namespace KeePass.Forms
 				peTarget.BackgroundColor = m_clrBackground;
 			else peTarget.BackgroundColor = Color.Empty;
 
-			peTarget.OverrideUrl = m_tbOverrideUrl.Text;
+			peTarget.OverrideUrl = m_cmbOverrideUrl.Text;
 
 			List<string> vNewTags = StrUtil.StringToTags(m_tbTags.Text);
 			peTarget.Tags.Clear();
@@ -842,6 +846,13 @@ namespace KeePass.Forms
 		private void CleanUpEx()
 		{
 			m_dynGenProfiles.MenuClick -= this.OnProfilesDynamicMenuClick;
+			m_dynGenProfiles.Clear();
+
+			m_btnBinOpen.SplitDropDownMenu = null;
+			m_dynBinOpen.MenuClick -= this.OnDynBinOpen;
+			m_dynBinOpen.Clear();
+			m_ctxBinOpen.Opening -= this.OnCtxBinOpenOpening;
+			m_ctxBinOpen.Dispose();
 
 			if(m_pwEditMode != PwEditMode.ViewReadOnlyEntry)
 				Program.Config.UI.Hiding.HideInEntryWindow = m_cbHidePassword.Checked;
@@ -850,6 +861,13 @@ namespace KeePass.Forms
 			m_icgPassword.Release();
 			m_cgExpiry.Release();
 
+			m_cmbOverrideUrl.OrderedImageList = null;
+			foreach(Image img in m_lOverrideUrlIcons)
+			{
+				if(img != null) img.Dispose();
+			}
+			m_lOverrideUrlIcons.Clear();
+
 			// Detach event handlers
 			m_lvStrings.SmallImageList = null;
 			m_lvBinaries.SmallImageList = null;
@@ -1205,7 +1223,7 @@ namespace KeePass.Forms
 
 			if(ipf.ShowDialog() == DialogResult.OK)
 			{
-				if(ipf.ChosenCustomIconUuid != PwUuid.Zero) // Custom icon
+				if(!ipf.ChosenCustomIconUuid.Equals(PwUuid.Zero)) // Custom icon
 				{
 					m_pwCustomIconID = ipf.ChosenCustomIconUuid;
 					UIUtil.SetButtonImage(m_btnIcon, m_pwDatabase.GetCustomIcon(
@@ -1387,6 +1405,8 @@ namespace KeePass.Forms
 				MemUtil.ZeroByteArray(pbCur);
 				pwp = PwProfile.DeriveFromPassword(psCur);
 			}
+			else if(e.ItemName == AutoGenProfile)
+				pwp = Program.Config.PasswordGenerator.AutoGeneratedPasswordsProfile;
 			else
 			{
 				foreach(PwProfile pwgo in PwGeneratorUtil.GetAllProfiles(false))
@@ -1413,16 +1433,30 @@ namespace KeePass.Forms
 		private void OnPwGenClick(object sender, EventArgs e)
 		{
 			m_dynGenProfiles.Clear();
-			m_dynGenProfiles.AddItem(DeriveFromPrevious, Properties.Resources.B16x16_CompFile);
-
 			m_dynGenProfiles.AddSeparator();
+			m_dynGenProfiles.AddItem(DeriveFromPrevious, Properties.Resources.B16x16_CompFile);
+			m_dynGenProfiles.AddItem(AutoGenProfile, Properties.Resources.B16x16_FileNew);
+
+			bool bHideBuiltIn = ((Program.Config.UI.UIFlags &
+				(ulong)AceUIFlags.HideBuiltInPwGenPrfInEntryDlg) != 0);
+
+			List<KeyValuePair<string, Image>> l = new List<KeyValuePair<string, Image>>();
 			foreach(PwProfile pwgo in PwGeneratorUtil.GetAllProfiles(true))
 			{
-				if(pwgo.Name != DeriveFromPrevious)
-					m_dynGenProfiles.AddItem(pwgo.Name,
-						Properties.Resources.B16x16_KOrganizer);
+				if((pwgo.Name != DeriveFromPrevious) && (pwgo.Name != AutoGenProfile))
+				{
+					if(bHideBuiltIn && PwGeneratorUtil.IsBuiltInProfile(pwgo.Name))
+						continue;
+
+					l.Add(new KeyValuePair<string, Image>(pwgo.Name,
+						Properties.Resources.B16x16_KOrganizer));
+				}
 			}
 
+			if(l.Count > 0) m_dynGenProfiles.AddSeparator();
+			foreach(KeyValuePair<string, Image> kvp in l)
+				m_dynGenProfiles.AddItem(kvp.Key, kvp.Value);
+
 			m_ctxPwGen.Show(m_btnGenPw, new Point(0, m_btnGenPw.Height));
 		}
 
@@ -1479,41 +1513,74 @@ namespace KeePass.Forms
 				KPRes.DocumentationHint);
 		}
 
-		private void OnBtnBinView(object sender, EventArgs e)
+		private bool GetSelBin(out string strDataItem, out ProtectedBinary pb)
 		{
+			strDataItem = null;
+			pb = null;
+
 			ListView.SelectedListViewItemCollection lvsic = m_lvBinaries.SelectedItems;
-			if((lvsic == null) || (lvsic.Count != 1)) return;
+			if((lvsic == null) || (lvsic.Count != 1)) return false; // No assert
 
-			string strDataItem = lvsic[0].Text;
-			ProtectedBinary pbinData = m_vBinaries.Get(strDataItem);
-			if(pbinData == null) { Debug.Assert(false); return; }
-			byte[] pbData = pbinData.ReadData();
+			strDataItem = lvsic[0].Text;
+			pb = m_vBinaries.Get(strDataItem);
+			if(pb == null) { Debug.Assert(false); return false; }
 
-			BinaryDataClass bdc = BinaryDataClassifier.Classify(strDataItem, pbData);
-			if(DataEditorForm.SupportsDataType(bdc) && (m_pwEditMode !=
-				PwEditMode.ViewReadOnlyEntry))
+			return true;
+		}
+
+		private void OpenSelBin(BinaryDataOpenOptions optBase)
+		{
+			string strDataItem;
+			ProtectedBinary pb;
+			if(!GetSelBin(out strDataItem, out pb)) return;
+
+			BinaryDataOpenOptions opt = ((optBase != null) ? optBase.CloneDeep() :
+				new BinaryDataOpenOptions());
+			if(m_pwEditMode == PwEditMode.ViewReadOnlyEntry)
 			{
-				DataEditorForm def = new DataEditorForm();
-				def.InitEx(strDataItem, pbData);
-				def.ShowDialog();
+				if(optBase == null)
+					opt.Handler = BinaryDataHandler.InternalViewer;
 
-				if(def.EditedBinaryData != null)
-				{
-					m_vBinaries.Set(strDataItem, new ProtectedBinary(
-						pbinData.IsProtected, def.EditedBinaryData));
-					UpdateEntryBinaries(false, true, strDataItem); // Update size
-				}
-
-				UIUtil.DestroyForm(def);
+				opt.ReadOnly = true;
 			}
-			else
+
+			ProtectedBinary pbMod = BinaryDataUtil.Open(strDataItem, pb, opt);
+			if(pbMod != null)
 			{
-				DataViewerForm dvf = new DataViewerForm();
-				dvf.InitEx(strDataItem, pbData);
-				UIUtil.ShowDialogAndDestroy(dvf);
+				m_vBinaries.Set(strDataItem, pbMod);
+				UpdateEntryBinaries(false, true, strDataItem); // Update size
 			}
 		}
 
+		private void OnBtnBinOpen(object sender, EventArgs e)
+		{
+			OpenSelBin(null);
+		}
+
+		private void OnDynBinOpen(object sender, DynamicMenuEventArgs e)
+		{
+			if(e == null) { Debug.Assert(false); return; }
+
+			BinaryDataOpenOptions opt = (e.Tag as BinaryDataOpenOptions);
+			if(opt == null) { Debug.Assert(false); return; }
+
+			OpenSelBin(opt);
+		}
+
+		private void OnCtxBinOpenOpening(object sender, CancelEventArgs e)
+		{
+			string strDataItem;
+			ProtectedBinary pb;
+			if(!GetSelBin(out strDataItem, out pb))
+			{
+				e.Cancel = true;
+				return;
+			}
+
+			BinaryDataUtil.BuildOpenWithMenu(m_dynBinOpen, strDataItem, pb,
+				(m_pwEditMode == PwEditMode.ViewReadOnlyEntry));
+		}
+
 		private void OnBtnTools(object sender, EventArgs e)
 		{
 			m_ctxTools.Show(m_btnTools, 0, m_btnTools.Height);
@@ -1660,7 +1727,7 @@ namespace KeePass.Forms
 
 		private void OnBinariesItemActivate(object sender, EventArgs e)
 		{
-			OnBtnBinView(sender, e);
+			OnBtnBinOpen(sender, e);
 		}
 
 		private void OnHistoryItemActivate(object sender, EventArgs e)
@@ -1798,7 +1865,7 @@ namespace KeePass.Forms
 			UpdateEntryBinaries(false, true, strNew);
 		}
 
-		private void BinDragAccept(DragEventArgs e)
+		private static void BinDragAccept(DragEventArgs e)
 		{
 			if(e == null) { Debug.Assert(false); return; }
 
@@ -1826,5 +1893,58 @@ namespace KeePass.Forms
 			}
 			catch(Exception) { Debug.Assert(false); }
 		}
+
+		private void InitOverridesBox()
+		{
+			List<KeyValuePair<string, Image>> l = new List<KeyValuePair<string, Image>>();
+
+			AddOverrideUrlItem(l, "cmd://{INTERNETEXPLORER} \"{URL}\"",
+				AppLocator.InternetExplorerPath);
+			AddOverrideUrlItem(l, "cmd://{FIREFOX} \"{URL}\"",
+				AppLocator.FirefoxPath);
+			AddOverrideUrlItem(l, "cmd://{OPERA} \"{URL}\"",
+				AppLocator.OperaPath);
+			AddOverrideUrlItem(l, "cmd://{GOOGLECHROME} \"{URL}\"",
+				AppLocator.ChromePath);
+			AddOverrideUrlItem(l, "cmd://{SAFARI} \"{URL}\"",
+				AppLocator.SafariPath);
+
+			Debug.Assert(m_cmbOverrideUrl.InvokeRequired);
+			VoidDelegate f = delegate()
+			{
+				try
+				{
+					Debug.Assert(!m_cmbOverrideUrl.InvokeRequired);
+					foreach(KeyValuePair<string, Image> kvp in l)
+					{
+						m_cmbOverrideUrl.Items.Add(kvp.Key);
+						m_lOverrideUrlIcons.Add(kvp.Value);
+					}
+
+					m_cmbOverrideUrl.OrderedImageList = m_lOverrideUrlIcons;
+				}
+				catch(Exception) { Debug.Assert(false); }
+			};
+			m_cmbOverrideUrl.Invoke(f);
+		}
+
+		private void AddOverrideUrlItem(List<KeyValuePair<string, Image>> l,
+			string strOverride, string strIconPath)
+		{
+			if(string.IsNullOrEmpty(strOverride)) { Debug.Assert(false); return; }
+
+			const int qSize = 16;
+
+			Image img = null;
+			string str = UrlUtil.GetQuotedAppPath(strIconPath ?? string.Empty);
+			str = str.Trim();
+			if(str.Length > 0) img = UIUtil.GetFileIcon(str, qSize, qSize);
+
+			if(img == null)
+				img = UIUtil.CreateScaledImage(m_ilIcons.Images[
+					(int)PwIcon.Console], qSize, qSize);
+
+			l.Add(new KeyValuePair<string, Image>(strOverride, img));
+		}
 	}
 }
