@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -66,6 +66,13 @@ namespace KeePass.Native
 		[DllImport("User32.dll", SetLastError = true, CharSet = CharSet.Auto)]
 		internal static extern int RegisterWindowMessage(string lpString);
 
+		// [DllImport("User32.dll")]
+		// internal static extern IntPtr GetDesktopWindow();
+
+		[DllImport("User32.dll", SetLastError = true, CharSet = CharSet.Auto)]
+		internal static extern IntPtr FindWindowEx(IntPtr hwndParent,
+			IntPtr hwndChildAfter, string lpszClass, string lpszWindow);
+
 		[DllImport("User32.dll")]
 		internal static extern IntPtr GetWindow(IntPtr hWnd, uint uCmd);
 
@@ -81,6 +88,10 @@ namespace KeePass.Native
 		[DllImport("User32.dll", EntryPoint = "GetClassLongPtr")]
 		private static extern IntPtr GetClassLongPtr64(IntPtr hWnd, int nIndex);
 
+		// [DllImport("User32.dll", SetLastError = true, CharSet = CharSet.Auto)]
+		// private static extern int GetClassName(IntPtr hWnd,
+		//	StringBuilder lpClassName, int nMaxCount);
+
 		[DllImport("User32.dll")]
 		[return: MarshalAs(UnmanagedType.Bool)]
 		internal static extern bool IsIconic(IntPtr hWnd);
@@ -94,12 +105,15 @@ namespace KeePass.Native
 
 		[DllImport("User32.dll", SetLastError = true, CharSet = CharSet.Auto)]
 		private static extern int GetWindowText(IntPtr hWnd,
-			[Out] StringBuilder lpString, int nMaxCount);
+			StringBuilder lpString, int nMaxCount);
 
 		[DllImport("User32.dll", SetLastError = true)]
 		[return: MarshalAs(UnmanagedType.Bool)]
 		internal static extern bool GetWindowRect(IntPtr hWnd, ref RECT lpRect);
 
+		// [DllImport("User32.dll")]
+		// internal static extern IntPtr GetActiveWindow();
+
 		[DllImport("User32.dll")]
 		private static extern IntPtr GetForegroundWindow(); // Private, is wrapped
 
@@ -140,7 +154,10 @@ namespace KeePass.Native
 		internal static extern uint MapVirtualKey(uint uCode, uint uMapType);
 
 		[DllImport("User32.dll", CharSet = CharSet.Auto)]
-		internal static extern ushort VkKeyScan(char ch); // TCHAR
+		internal static extern ushort VkKeyScan(char ch);
+
+		[DllImport("User32.dll", CharSet = CharSet.Auto)]
+		internal static extern ushort VkKeyScanEx(char ch, IntPtr hKL);
 
 		[DllImport("User32.dll")]
 		internal static extern ushort GetKeyState(int vKey);
@@ -260,9 +277,12 @@ namespace KeePass.Native
 		[DllImport("Kernel32.dll")]
 		internal static extern uint GetCurrentThreadId();
 
-		[DllImport("Imm32.dll")]
-		[return: MarshalAs(UnmanagedType.Bool)]
-		internal static extern bool ImmDisableIME(uint idThread);
+		// [DllImport("Imm32.dll")]
+		// [return: MarshalAs(UnmanagedType.Bool)]
+		// internal static extern bool ImmDisableIME(uint idThread);
+
+		// [DllImport("Imm32.dll")]
+		// internal static extern IntPtr ImmAssociateContext(IntPtr hWnd, IntPtr hIMC);
 
 		[DllImport("Kernel32.dll", SetLastError = true, CharSet = CharSet.Auto)]
 		internal static extern IntPtr CreateFile(string lpFileName,
@@ -338,9 +358,9 @@ namespace KeePass.Native
 		// internal extern static uint DrawThemeBackground(IntPtr hTheme, IntPtr hdc,
 		//	int iPartId, int iStateId, ref RECT pRect, ref RECT pClipRect);	
 
-		[DllImport("Gdi32.dll")]
-		[return: MarshalAs(UnmanagedType.Bool)]
-		internal static extern bool DeleteObject(IntPtr hObject);
+		// [DllImport("Gdi32.dll")]
+		// [return: MarshalAs(UnmanagedType.Bool)]
+		// internal static extern bool DeleteObject(IntPtr hObject);
 
 		[DllImport("User32.dll")]
 		[return: MarshalAs(UnmanagedType.Bool)]
@@ -374,5 +394,47 @@ namespace KeePass.Native
 		[DllImport("User32.dll", CharSet = CharSet.Auto)]
 		internal static extern int MessageBox(IntPtr hWnd, string lpText,
 			string lpCaption, [MarshalAs(UnmanagedType.U4)] MessageBoxFlags uType);
+
+		// [DllImport("User32.dll")]
+		// [return: MarshalAs(UnmanagedType.Bool)]
+		// internal static extern bool SetProcessDPIAware();
+
+		[DllImport("Kernel32.dll")]
+		internal static extern IntPtr CreateToolhelp32Snapshot(
+			[MarshalAs(UnmanagedType.U4)] ToolHelpFlags dwFlags, uint th32ProcessID);
+
+		[DllImport("Kernel32.dll", CharSet = CharSet.Auto)]
+		[return: MarshalAs(UnmanagedType.Bool)]
+		internal static extern bool Process32First(IntPtr hSnapshot,
+			ref PROCESSENTRY32 lppe);
+
+		[DllImport("Kernel32.dll", CharSet = CharSet.Auto)]
+		[return: MarshalAs(UnmanagedType.Bool)]
+		internal static extern bool Process32Next(IntPtr hSnapshot,
+			ref PROCESSENTRY32 lppe);
+
+		// [DllImport("Kernel32.dll", SetLastError = true)]
+		// internal static extern IntPtr OpenProcess(uint dwDesiredAccess,
+		//	[MarshalAs(UnmanagedType.Bool)] bool bInheritHandle, uint dwProcessId);
+
+		// [DllImport("User32.dll")]
+		// [return: MarshalAs(UnmanagedType.Bool)]
+		// internal static extern bool IsImmersiveProcess(IntPtr hProcess);
+
+		[DllImport("Kernel32.dll", CharSet = CharSet.Auto)]
+		internal static extern IntPtr CreateActCtx(ref ACTCTX pActCtx);
+
+		[DllImport("Kernel32.dll")]
+		internal static extern void ReleaseActCtx(IntPtr hActCtx);
+
+		[DllImport("Kernel32.dll")]
+		[return: MarshalAs(UnmanagedType.Bool)]
+		internal static extern bool ActivateActCtx(IntPtr hActCtx,
+			ref UIntPtr lpCookie);
+
+		[DllImport("Kernel32.dll")]
+		[return: MarshalAs(UnmanagedType.Bool)]
+		internal static extern bool DeactivateActCtx(uint dwFlags,
+			UIntPtr ulCookie);
 	}
 }
