@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -126,7 +126,7 @@ namespace KeePass.UI
 					EnsureVisible(lviChangeTo.Index);
 					UIUtil.SetFocusedItem(this, lviChangeTo, true);
 
-					e.Handled = true;
+					UIUtil.SetHandled(e, true);
 					return true;
 				}
 			}
