@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -80,6 +80,21 @@ namespace KeePass.UI
 		Question = 1
 	}
 
+	/* internal enum VtdMsg
+	{
+		Created = 0,
+		Navigated = 1,
+		ButtonClicked = 2,
+		HyperlinkClicked = 3,
+		Timer = 4,
+		Destroyed = 5,
+		RadioButtonClicked = 6,
+		DialogConstructed = 7,
+		VerificationClicked = 8,
+		Help = 9,
+		ExpandoButtonClicked = 10
+	} */
+
 	// Pack = 4 required for 64-bit compatibility
 	[StructLayout(LayoutKind.Sequential, CharSet = CharSet.Auto, Pack = 4)]
 	internal struct VtdButton
@@ -147,7 +162,7 @@ namespace KeePass.UI
 		[MarshalAs(UnmanagedType.LPWStr)]
 		public string pszFooter;
 
-		public IntPtr pfCallback; // PFTASKDIALOGCALLBACK
+		public TaskDialogCallbackProc pfCallback;
 		public IntPtr lpCallbackData;
 		public uint cxWidth;
 
@@ -179,12 +194,15 @@ namespace KeePass.UI
 			pszCollapsedControlText = null;
 			hFooterIcon = IntPtr.Zero;
 			pszFooter = null;
-			pfCallback = IntPtr.Zero; // PFTASKDIALOGCALLBACK
+			pfCallback = null;
 			lpCallbackData = IntPtr.Zero;
 			cxWidth = 0;
 		}
 	}
 
+	internal delegate int TaskDialogCallbackProc(IntPtr hwnd, uint uNotification,
+		UIntPtr wParam, IntPtr lParam, IntPtr lpRefData);
+
 	public sealed class VistaTaskDialog
 	{
 		private const int VtdConfigSize32 = 96;
@@ -196,6 +214,8 @@ namespace KeePass.UI
 
 		private List<VtdButton> m_vButtons = new List<VtdButton>();
 
+		// private IntPtr m_hWnd = IntPtr.Zero;
+
 		public string WindowTitle
 		{
 			get { return m_cfg.pszWindowTitle; }
@@ -400,16 +420,25 @@ namespace KeePass.UI
 			try { ButtonsToPtr(); }
 			catch(Exception) { Debug.Assert(false); return false; }
 
+			// m_cfg.pfCallback = this.OnTaskDialogCallback;
+
 			try
 			{
-				if(NativeMethods.TaskDialogIndirect(ref m_cfg, out pnButton,
-					out pnRadioButton, out bVerification) != 0)
-					throw new NotSupportedException();
+				using(EnableThemingInScope etis = new EnableThemingInScope(true))
+				{
+					if(NativeMethods.TaskDialogIndirect(ref m_cfg, out pnButton,
+						out pnRadioButton, out bVerification) != 0)
+						throw new NotSupportedException();
+				}
 			}
 			catch(Exception) { return false; }
 			finally
 			{
-				try { FreeButtonsPtr(); }
+				try
+				{
+					// m_cfg.pfCallback = null;
+					FreeButtonsPtr();
+				}
 				catch(Exception) { Debug.Assert(false); }
 			}
 
@@ -418,6 +447,25 @@ namespace KeePass.UI
 			return true;
 		}
 
+		/* private int OnTaskDialogCallback(IntPtr hwnd, uint uNotification,
+			UIntPtr wParam, IntPtr lParam, IntPtr lpRefData)
+		{
+			if((uNotification == (uint)VtdMsg.Created) ||
+				(uNotification == (uint)VtdMsg.DialogConstructed))
+				UpdateHWnd(hwnd);
+			else if(uNotification == (uint)VtdMsg.Destroyed)
+				UpdateHWnd(IntPtr.Zero);
+
+			return 0;
+		}
+
+		private void UpdateHWnd(IntPtr hWnd)
+		{
+			if(hWnd != m_hWnd) { } // Unregister m_hWnd
+			// Register hWnd
+			m_hWnd = hWnd;
+		} */
+
 		public static bool ShowMessageBox(string strContent, string strMainInstruction,
 			string strWindowTitle, VtdIcon vtdIcon, Form fParent)
 		{
