@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -451,7 +451,7 @@ namespace KeePass.Util
 			return null;
 		}
 
-		private static DataObject CreateProtectedDataObject(string strText)
+		/* private static DataObject CreateProtectedDataObject(string strText)
 		{
 			DataObject d = new DataObject();
 			AttachIgnoreFormat(d);
@@ -487,7 +487,7 @@ namespace KeePass.Util
 				doData.SetData(ClipboardIgnoreFormatName, false, PwDefs.ProductName);
 			}
 			catch(Exception) { Debug.Assert(false); }
-		}
+		} */
 
 		public static bool ContainsText()
 		{
