@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -101,7 +101,7 @@ namespace KeePass.Util
 		private static int MenuGetImageIndex(PwDocument ds, PwIcon pwID,
 			PwUuid pwCustomID)
 		{
-			if((pwCustomID != PwUuid.Zero) && (ds ==
+			if(!pwCustomID.Equals(PwUuid.Zero) && (ds ==
 				Program.MainForm.DocumentManager.ActiveDocument))
 			{
 				return (int)PwIcon.Count +
