@@ -1,6 +1,6 @@
-/*
+﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -592,9 +592,9 @@ namespace KeePassLib.Cryptography
 				case '\u00D1':
 				case '\u00F1': ch = 'n'; break;
 				case '0':
-				case '':
 				case '*':
-				case '\u00A4':
+				case '\u00A4': // Currency
+				case '\u00B0': // Degree
 				case '\u00D8':
 				case '\u00F8': ch = 'o'; break;
 				case '\u00AE': ch = 'r'; break;
