@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2013 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -204,6 +204,9 @@ namespace KeePassLib
 		IgnoreHistory = 0x10,
 		IgnoreLastBackup = 0x20,
 
+		// For groups:
+		PropertiesOnly = 0x40,
+
 		IgnoreTimes = (IgnoreLastAccess | IgnoreLastMod)
 	}
 
@@ -246,4 +249,22 @@ namespace KeePassLib
 	//	NOr = 3,
 	//	NAnd = 4
 	// }
+
+	[Flags]
+	public enum AppRunFlags
+	{
+		None = 0,
+		GetStdOutput = 1,
+		WaitForExit = 2,
+
+		// This flag prevents any handles being garbage-collected
+		// before the started process has terminated, without
+		// blocking the current thread;
+		// https://sourceforge.net/p/keepass/patches/84/
+		GCKeepAlive = 4,
+
+		// https://sourceforge.net/p/keepass/patches/85/
+		DoEvents = 8,
+		DisableForms = 16
+	}
 }
